﻿--[[
Name: PratChannelColorMemory
Revision: $Revision: 24018 $
Author(s): Sylvanaar
Inspired by: ConsisTint By Karl Isenberg (AnduinLothar)
Website: http://www.wowace.com/files/index.php?path=Prat/
Documentation: http://www.wowace.com/wiki/Prat/Integrated_Modules#ChannelColorMemory
SVN: http://svn.wowace.com/wowace/trunk/Prat/
Description: Module for Prat that remembers the colors of channels by channel name (default=on).
Dependencies: Prat
]]

local L = AceLibrary("AceLocale-2.2"):new("PratChannelColorMemory")

L:RegisterTranslations("enUS", function() return {
    ["ChannelColorMemory"] = true,
    ["Remembers the colors of channels by channel name."] = true,
    ["(%w+)%s?(.*)"] = true,
    ["Toggle"] = true,
    ["Toggle the module on and off."] = true,
} end)

L:RegisterTranslations("zhCN", function() return {
	["ChannelColorMemory"] = "频道颜色储存",
    ["Remembers the colors of channels by channel name."] = "还原频道名称的颜色设置",
	["(%w+)%s?(.*)"] = "(.+)%s?(.*)",
	["Toggle"] = "切换",
	["Toggle the module on and off."] = "切换此模块的打开与关闭。",
} end)

-- L:RegisterTranslations("koKR", function() return {
-- 	["ChannelColorMemory"] = "채널색상기억",
-- 	["Remembers the colors of channels by channel name."] = "채널명에 따른 채널의 색상을 기억합니다.",
-- 	["(%w+)%s?(.*)"] = "(.+)%s?(.*)",
-- 	["Toggle"] = "사용",
-- 	["Toggle the module on and off."] = "기능 사용 여부를 결정합니다.",
-- } end)

L:RegisterTranslations("zhTW", function() return {
    ["ChannelColorMemory"] = "頻道顏色儲存",
    ["Remembers the colors of channels by channel name."] = "還原頻道名稱的顏色設置",
    ["(%w+)%s?(.*)"] = "(.+)%s?(.*)",
    ["Toggle"] = "切換",
    ["Toggle the module on and off."] = "切換打開或關閉此模組。",
} end)

L:RegisterTranslations("esES", function() return {
    ["ChannelColorMemory"] = "Memoria de Color de Canal",
    ["Remembers the colors of channels by channel name."] = "Recuerda los colores de los canales por nombre de canal.",
    ["(%w+)%s?(.*)"] = "(%w+)%s?(.*)",
    ["Toggle"] = "Activar",
    ["Toggle the module on and off."] = "Activa y desactiva este m\195\179dulo.",
} end)

L:RegisterTranslations("deDE", function() return {
    ["ChannelColorMemory"] = "Kanal Farben Merken",
    ["Remembers the colors of channels by channel name."] = "Merkt sich die Kanal Farben nach Kanal Name.",
    ["(%w+)%s?(.*)"] = "(%w+)%s?(.*)",
    ["Toggle"] = "Einschalten",
    ["Toggle the module on and off."] = "Schaltet dieses Modul an und aus.",
} end)

Prat_ChannelColorMemory = Prat:NewModule(Prat:RequestModuleName("PratChannelColorMemory"))

Prat_ChannelColorMemory.revision = tonumber(string.sub("$Revision: 24018 $", 12, -3))
Prat_ChannelColorMemory.moduleName = L["ChannelColorMemory"]
Prat_ChannelColorMemory.moduleDesc = L["Remembers the colors of channels by channel name."]

Prat_ChannelColorMemory.defaultDB = {
    on = true,
    colors = {},
}

Prat_ChannelColorMemory.moduleOptions = {}

local cat = Prat.Categories
Prat_ChannelColorMemory.Categories = { cat.CHANNEL, cat.FORMATTING }

function Prat_ChannelColorMemory:OnModuleEnable()
	self:RegisterEvent("UPDATE_CHAT_COLOR")
	self:RegisterEvent("CHAT_MSG_CHANNEL_NOTICE")
end

--[[------------------------------------------------
	Core Functions
------------------------------------------------]]--

function Prat_ChannelColorMemory:UPDATE_CHAT_COLOR(ChatType, cr,cg,cb)
	if (ChatType) then
			local number = string.gmatch(arg1, "CHANNEL(%d+)")()
			if ( number ) then
				local _, name = GetChannelName(number);
				if ( name ) then
					local name, zoneSuffix = string.gmatch(name, L["(%w+)%s?(.*)"])();

					local color = self.db.profile.colors[name];
					if (not color) then
						self.db.profile.colors[name] = {r=cr, g=cg, b=cb};
					else
						color.r=cr
						color.g=cg
						color.b=cb
					end
				end
			end
	end
end

function Prat_ChannelColorMemory:CHAT_MSG_CHANNEL_NOTICE(NoticeType,a2,a3,LongName,a5,a6,a7,number, cname)
	if (not strfind(LongName, "%d+%. .*")) then
		return;
	elseif (arg1 == "YOU_JOINED") then
		local name, zoneSuffix = string.gmatch(cname, L["(%w+)%s?(.*)"])();
		local color = self.db.profile.colors[name];
		if (color) then
			ChangeChatColor("CHANNEL"..number, color.r, color.g, color.b);
		else
			color = ChatTypeInfo["CHANNEL"..number];
			self.db.profile.colors[name] = {r=color.r, g=color.g, b=color.b};
		end
	end
end
