﻿--[[
Name: PratChannelSeparator
Revision: $Revision: 24018 $
Author(s): Krtek (krtek4@gmail.com)
           Sylvanaar
Website: http://www.wowace.com/files/index.php?path=Prat/
Documentation: http://www.wowace.com/wiki/Prat/Integrated_Modules#ChannelSeparator
SVN: http://svn.wowace.com/wowace/trunk/Prat/
Description: Module for Prat that separates chat channels in the chat setting menu (default=on).
Dependencies: Prat
]]

local L = AceLibrary("AceLocale-2.2"):new("PratChannelSeparator")

L:RegisterTranslations("enUS", function() return {
    ["ChannelSeparator"] = true,
    ["Separates chat channels in chat setting menu."] = true,
    ["Toggle"] = true,
    ["Toggle the module on and off."] = true,
} end)

L:RegisterTranslations("zhCN", function() return {
	["ChannelSeparator"] = "频道分离",
	["Separates chat channels in chat setting menu."] = "分离聊天频道设置菜单。",
	["Toggle"] = "切换",
	["Toggle the module on and off."] = "切换此模块的打开与关闭。",
} end)

-- L:RegisterTranslations("koKR", function() return {
-- 	["ChannelSeparator"] = "채널구분",
-- 	["Separates chat channels in chat setting menu."] = "대화 설정 메뉴에 대화 채널을 구분합니다.",
-- 	["Toggle"] = "사용",
-- 	["Toggle the module on and off."] = "기능 사용 여부를 결정합니다.",
-- } end)

L:RegisterTranslations("zhTW", function() return {
    ["ChannelSeparator"] = "頻道分離",
    ["Separates chat channels in chat setting menu."] = "在聊天設定選單中分離聊天頻道。",
    ["Toggle"] = "切換",
    ["Toggle the module on and off."] = "切換打開或關閉此模組。",
} end)

L:RegisterTranslations("esES", function() return {
    ["ChannelSeparator"] = "Separador de Canal",
    ["Separates chat channels in chat setting menu."] = "Separa los canales de chat en el men\195\186 de ajustes del chat",
    ["Toggle"] = "Activar",
    ["Toggle the module on and off."] = "Activa y desactiva este m\195\179dulo.",
} end)

L:RegisterTranslations("deDE", function() return {
    ["ChannelSeparator"] = "Kanal Trennen",
    ["Separates chat channels in chat setting menu."] = "Trennt Chat Kan\195\164le in dem Chateinstellungs Men\195\188.",
    ["Toggle"] = "Einschalten",
    ["Toggle the module on and off."] = "Schaltet das Modul an und aus.",
} end)

BATTLEGROUND = TEXT(CHAT_MSG_BATTLEGROUND)

Prat_ChannelSeparator = Prat:NewModule(Prat:RequestModuleName("PratChannelSeparator"))

Prat_ChannelSeparator.revision = tonumber(string.sub("$Revision: 24018 $", 12, -3))

Prat_ChannelSeparator.defaultDB = {
    on = true,
}

Prat_ChannelSeparator.status = "TAINT"

local cat = Prat.Categories
Prat_ChannelSeparator.Categories = { cat.CHANNEL, cat.FRAME }

Prat_ChannelSeparator.moduleOptions = {}

function Prat_ChannelSeparator:GetModuleOptions()
    self.moduleOptions = {
        name = L["ChannelSeparator"],
        desc = L["Separates chat channels in chat setting menu."],
        type = "group",
        args = {}
    }
	
	return self.moduleOptions 
end

function Prat_ChannelSeparator:OnModuleInit()
    self.OriginalChatTypeGroup = {}
    self.OriginalChannelMenuChatTypeGroups = {}
end

function Prat_ChannelSeparator:OnModuleEnable()
    self.OriginalChatTypeGroup = ChatTypeGroup
    ChatTypeGroup["GUILD"] = {
        "CHAT_MSG_GUILD",
        "GUILD_MOTD",
        "CHAT_MSG_OFFICER",
    };
    ChatTypeGroup["PARTY"] = {
        "CHAT_MSG_PARTY",
    };
    ChatTypeGroup["RAID"] = {
        "CHAT_MSG_RAID",
        "CHAT_MSG_RAID_LEADER",
        "CHAT_MSG_RAID_WARNING",
    };
    ChatTypeGroup["BATTLEGROUND"] = {
        "CHAT_MSG_BATTLEGROUND",
        "CHAT_MSG_BATTLEGROUND_LEADER",
    };
    self.OriginalChannelMenuChatTypeGroups = ChannelMenuChatTypeGroups
    ChannelMenuChatTypeGroups = {};
    ChannelMenuChatTypeGroups[1] = "SAY";
    ChannelMenuChatTypeGroups[2] = "YELL";
    ChannelMenuChatTypeGroups[3] = "GUILD";
    ChannelMenuChatTypeGroups[4] = "WHISPER";
    ChannelMenuChatTypeGroups[5] = "PARTY";
    ChannelMenuChatTypeGroups[6] = "RAID";
    ChannelMenuChatTypeGroups[7] = "BATTLEGROUND";
    local add = false
    for i=1,NUM_CHAT_WINDOWS do
    	frame = getglobal("ChatFrame"..i)
    	add = false
    	local messageTypeList = frame.messageTypeList;
    	if ( messageTypeList ) then
			for joinedIndex, joinedValue in pairs(messageTypeList) do
				if ( joinedValue == "PARTY" ) then
					add = true
				end
			end

			if add then
		    	ChatFrame_AddMessageGroup(frame, "RAID")
		    	ChatFrame_AddMessageGroup(frame, "BATTLEGROUND")
			end
		end
    end
end

function Prat_ChannelSeparator:OnModuleDisable()
    ChatTypeGroup = {}
    ChatTypeGroup = self.OriginalChatTypeGroup
    ChannelMenuChatTypeGroups = {}
    ChannelMenuChatTypeGroups = self.OriginalChannelMenuChatTypeGroups
end