﻿--[[
Name: PratChannelSticky
Revision: $Revision: 24065 $
Author(s): Curney (asml8ed@gmail.com)
           Krtek (krtek4@gmail.com)
Inspired by: idChat2_StickyChannels by Industrial
Website: http://www.wowace.com/files/index.php?path=Prat/
Documentation: http://www.wowace.com/wiki/Prat/Integrated_Modules#ChannelSticky
SVN: http://svn.wowace.com/wowace/trunk/Prat/
Description: Module for Prat that toggles sticky of different chat channel types on and off (default=on).
Dependencies: Prat
]]

local L = AceLibrary("AceLocale-2.2"):new("PratChannelSticky")

L:RegisterTranslations("enUS", function() return {
    ["ChannelSticky"] = true,
    ["Chat channel sticky options."] = true,
    ["ChatType"] = true,
    ["Per chat type options."] = true,
    ["Channel"] = true,
    ["%sSticky"] = true,
    ["Toggles sticky on and off for %s."] = true,
	["Sticky Frame Chat Type"] = true,
    ["Toggle remembering the chat type last used per chat frame."] = true,
} end)

L:RegisterTranslations("zhCN", function() return {
	["ChannelSticky"] = "固定频道",
	["Chat channel sticky options."] = "固定聊天频道选项。",
	["ChatType"] = "聊天分类",
	["Per chat type options."] = "聊天类型选项。",
	["Say"] = "说",
	["Whisper"] = "密语",
	["Yell"] = "喊",
	["Party"] = "队伍",
	["Guild"] = "公会",
	["Officer"] = "官员",
	["Raid"] = "团队",
	["RaidWarning"] = "团队报警",
	["Battleground"] = "战场",
	["Channel"] = "频道",
	["Emote"] = "表情",
    ["%sSticky"] = "固定%s",
	["Toggles sticky on and off for %s."] = "切换固定%s频道.",
	["Toggle"] = "切换",
	["Toggle the module on and off."] = "切换此模块的打开与关闭。",
} end)

-- L:RegisterTranslations("koKR", function() return {
-- 	["ChannelSticky"] = "채널고정",
-- 	["Chat channel sticky options."] = "대화 채널 고정 설정입니다.",
-- 	["ChatType"] = "대화종류",
-- 	["Per chat type options."] = "대화종류에 따른 설정입니다.",
-- 	["Channel"] = "채널",
-- 	["%sSticky"] = "%s고정",
-- 	["Toggles sticky on and off for %s."] = "%s에 대한 고정 기능을 사용합니다.",
-- 	["Sticky Frame Chat Type"] = "대화창에 따른 대화 종류 고정",
-- 	["Toggle remembering the chat type last used per chat frame."] = "대화창에 따라 마지막에 사용된 대화 종류를 기억합니다.",
-- } end)

L:RegisterTranslations("zhTW", function() return {
    ["ChannelSticky"] = "固定頻道",
    ["Chat channel sticky options."] = "固定聊天頻道選項。",
    ["ChatType"] = "聊天分類",
    ["Per chat type options."] = "聊天類型選項。",
    ["Say"] = "說",
    ["Whisper"] = "密語",
    ["Yell"] = "喊",
    ["Party"] = "隊伍",
    ["Guild"] = "公會",
    ["Officer"] = "公會管理",
    ["Raid"] = "團隊",
    ["RaidWarning"] = "團隊報警",
    ["Battleground"] = "戰場",
    ["Channel"] = "頻道",
    ["Emote"] = "表情",
    ["%sSticky"] = "固定%s",
    ["Toggles sticky on and off for %s."] = "切換固定%s頻道。",
    ["Toggle"] = "切換",
    ["Toggle the module on and off."] = "切換打開或關閉此模組。",
} end)

L:RegisterTranslations("esES", function() return {
    ["ChannelSticky"] = "Canales Pegajosos",
    ["Chat channel sticky options."] = "Opciones para canales pegajosos",
    ["ChatType"] = "Tipo de Chat",
    ["Per chat type options."] = "Opciones por tipo de chat",
    ["Channel"] = "Canal",
    ["%sSticky"] = "%s Pegajoso",
    ["Toggles sticky on and off for %s."] = "Determina si %s es pegajoso",
	["Sticky Frame Chat Type"] = "Tipo de Marco de Chat Pegajoso",
    ["Toggle remembering the chat type last used per chat frame."] = "Determina si se recuerda el \195\186ltimo tipo de chat usado por marco de chat",
} end)

L:RegisterTranslations("deDE", function() return {
    ["ChannelSticky"] = "Sticky Channel", -- channels are called "Channel" in ingame help 
    ["Chat channel sticky options."] = "Channel Sticky Optionen",
    ["ChatType"] = "Chat Art",
    ["Per chat type options."] = "Nach Chat Art Optionen",
    ["Channel"] = "Channel",
--    ["Emote"] = "Emote",
    ["%sSticky"] = "%s Sticky",
    ["Toggles sticky on and off for %s."] = "Schaltet Sticky an und aus f\195\188r %s.",
--	["Sticky Frame Chat Type"] = true,
--  ["Toggle remembering the chat type last used per chat frame."] = true,
} end)

local chatList = {
    "SAY",
    "WHISPER",
    "YELL",
    "PARTY",
    "GUILD",
    "OFFICER",
    "RAID",
    "RAID_WARNING",
    "BATTLEGROUND",
    "CHANNEL",
    "EMOTE",
}

function CLR:StkyChatType(text, type) return self:Colorize(Prat_ChannelSticky:GetChatCLR(type), text) end

Prat_ChannelSticky = Prat:NewModule(Prat:RequestModuleName("PratChannelSticky"))

Prat_ChannelSticky.revision = tonumber(string.sub("$Revision: 24065 $", 12, -3))
Prat_ChannelSticky.status = "TAINT"

Prat_ChannelSticky.defaultDB = {
        on = true,
        say = true,
        whisper = true,
        yell = true,
        party = true,
        guild = true,
        officer = true,
        raid = true,
        raid_warning = true,
        battleground = true,
        channel = true,
        emote = true,
        stickychan = false,
}

Prat_ChannelSticky.moduleOptions = {}

local cat = Prat.Categories
Prat_ChannelSticky.Categories = { cat.CHANNEL, cat.BEHAVIOR }

function Prat_ChannelSticky:GetModuleOptions()
    self.moduleOptions = {
        name = L["ChannelSticky"],
        desc = L["Chat channel sticky options."],
        type = "group",
        args = {
            chattype = {
                name = L["ChatType"],
                desc = L["Per chat type options."],
                type = "group",
                args = {},
            },
            stickychan = {
                name = L["Sticky Frame Chat Type"],
                desc = L["Toggle remembering the chat type last used per chat frame."],
                type = "toggle",
                get = function() return self.db.profile.stickychan end,
                set = function(v)
                    self.db.profile.stickychan = v
                    self:StickyFrameChan(v)
                end,
            },
    	}
    }
    
    self:BuildChannelList()
    
    
    return self.moduleOptions
end


function Prat_ChannelSticky:OnModuleEnable()
	self:BuildChannelList()
	self:RegisterEvent("UPDATE_CHAT_COLOR");
    self:Stickum("SAY",self.db.profile.say)
    self:Stickum("WHISPER",self.db.profile.whisper)
    self:Stickum("YELL",self.db.profile.yell)
    self:Stickum("PARTY",self.db.profile.party)
    self:Stickum("GUILD",self.db.profile.guild)
    self:Stickum("OFFICER",self.db.profile.officer)
    self:Stickum("RAID",self.db.profile.raid)
    self:Stickum("RAID_WARNING",self.db.profile.raid_warning)
    self:Stickum("BATTLEGROUND",self.db.profile.battleground)
    self:Stickum("CHANNEL",self.db.profile.channel)
    self:Stickum("EMOTE",self.db.profile.emote)

	self:StickyFrameChan(self.db.profile.stickychan)
end

function Prat_ChannelSticky:OnModuleDisable()
    self:Stickum("SAY",false)
    self:Stickum("WHISPER",false)
    self:Stickum("YELL",false)
    self:Stickum("PARTY",false)
    self:Stickum("GUILD",false)
    self:Stickum("OFFICER",false)
    self:Stickum("RAID",false)
    self:Stickum("RAID_WARNING",false)
    self:Stickum("BATTLEGROUND",false)
    self:Stickum("CHANNEL",false)
    self:Stickum("EMOTE",false)

    self:StickyFrameChan(false)
end

--[[------------------------------------------------
	Core Functions
------------------------------------------------]]--

--
-- Options Builder Functions
--

function Prat_ChannelSticky:BuildChannelList()
	local o = self.moduleOptions.args.chattype.args
	for _,va in ipairs(chatList) do
		local val = va
		local chan
		if val ~= "CHANNEL" then
			chan = TEXT(getglobal("CHAT_MSG_"..val))
		else
			chan = L["Channel"]
		end
		o[val] = {
	        name = string.format(L["%sSticky"], CLR:StkyChatType(string.gsub(chan, " ", ""), val)),
	        desc = string.format(L["Toggles sticky on and off for %s."], chan),
	        type = "toggle",
	        get = function() return self.db.profile[string.lower(val)] end,
	        set = function(v)
	            self.db.profile[string.lower(val)] = v
	            self:Stickum(val ,v)
	        end
	    }
	end
end

function Prat_ChannelSticky:UPDATE_CHAT_COLOR()
	self:BuildChannelList()
end

function Prat_ChannelSticky:StickyFrameChan(enabled)
    if not enabled then
		self:UnhookAll()
	else
		self.perframe = {}
		self.perframechannum = {}
		self:Hook("ChatFrame_OpenChat", true)
		self:SecureHook("ChatEdit_OnEscapePressed")
		self:SecureHook("SendChatMessage")
		self:SecureHook("ChatEdit_OnEnterPressed")
	end
end

function Prat_ChannelSticky:ChatFrame_OpenChat(text, chatFrame)
	if ( not chatFrame ) then
		chatFrame = SELECTED_CHAT_FRAME
	end

	local chatFrameN = chatFrame:GetName()

	self:Debug("ChatFrame_OpenChat() - "..chatFrameN.." -> "..(chatFrame.editBox:GetAttribute("chatType") or "nil"))

	if chatFrame.editBox:GetAttribute("chatType") == "WHISPER" then
	self:Debug("ChatFrame_OpenChat() - "..(chatFrame.editBox:GetAttribute("chatType") or "nil").." -> "..(chatFrame.editBox:GetAttribute("tellTarget") or "nil"))

	elseif self.perframe[chatFrameN] then
		self:Debug("ChatFrame_OpenChat() - "..chatFrameN.." was -> "..self.perframe[chatFrameN])
		chatFrame.editBox:SetAttribute("channelTarget", self.perframechannum[chatFrameN]);

		chatFrame.editBox:SetAttribute("chatType", self.perframe[chatFrameN]);
		chatFrame.editBox:SetAttribute("stickyType", self.perframe[chatFrameN]);
	end
	self.hooks["ChatFrame_OpenChat"](text, chatFrame)
end

function Prat_ChannelSticky:SendChatMessage(msg, chatType, language, channel)
	self:Debug("SendChatMessage() - "..chatType.."["..(channel or "").."] -> "..msg)
	if self.memoNext then
	self:Debug("SendChatMessage() - "..self.memoNext.." -> "..chatType.."["..(channel or "").."]")
		self.perframe[self.memoNext] = chatType
		self.perframechannum[self.memoNext] = channel
	end
end

function Prat_ChannelSticky:ChatEdit_OnEscapePressed()
	self:Debug("ChatEdit_OnEscapePressed()")
	self.memoNext = nil
end

function Prat_ChannelSticky:ChatEdit_OnEnterPressed()
	self:Debug("ChatEdit_OnEnterPressed()")
	local chatFrameN = SELECTED_CHAT_FRAME:GetName()
	local chatType = this:GetAttribute("chatType")
	local channel = this:GetAttribute("channelTarget")
	self:Debug("ChatEdit_OnEnterPressed() - Saved "..chatFrameN.." -> "..chatType.."["..(channel or "").."]")
	self.perframe[chatFrameN] = chatType
	self.perframechannum[chatFrameN] = channel
	self.memoNext = nil
end



function Prat_ChannelSticky:GetChatCLR(name)
	local info = ChatTypeInfo[name];

	if not info then 
		return CLR.COLOR_NONE
	end
	
	return CLR:GetHexColor(info)
end

--
-- Toggle sticky parameter
--

function Prat_ChannelSticky:Stickum(channel,stickied)
    if stickied then
        ChatTypeInfo[channel].sticky = 1
    else
        ChatTypeInfo[channel].sticky = 0
    end
end