﻿--[[
Name: PratChatFrames
Revision: $Revision: 24018 $
Author(s): Curney (asml8ed@gmail.com)
Website: http://www.wowace.com/files/index.php?path=Prat/
Documentation: http://www.wowace.com/wiki/Prat/Integrated_Modules#ChatFrames
SVN: http://svn.wowace.com/wowace/trunk/Prat/
Description: Module for Prat that adds options for changing chat window parameters.
Dependencies: Prat
]]

local L = AceLibrary("AceLocale-2.2"):new("PratChatFrames")

L:RegisterTranslations("enUS", function() return {
    ["ChatFrames"] = true,
    ["Chat window frame parameter options."] = true,
    ["sizing_name"] = "Chatframe Sizing",
    ["sizing_desc"] = "Set Chatframe Size Constratints.",
    ["minchatwidth_name"] = "Set Minimum Width",
    ["minchatwidth_desc"] = "Sets the minimum width for all chat windows.",
    ["minchatheight_name"] = "Set Minimum Height",
    ["minchatheight_desc"] = "Sets the minimum height for all chat windows.",
    ["maxchatwidth_name"] = "Set Maximum Width",
    ["maxchatwidth_desc"] = "Sets the maximum width for all chat windows.",
    ["maxchatheight_name"] = "Set Maximum Height",
    ["maxchatheight_desc"] = "Sets the maximum height for all chat windows.",
    ["restore_name"] = "Select Main Chat Frame On Load",
    ["restore_desc"] = "Automatically select the first chat frame and make it active on load.",
} end)

-- L:RegisterTranslations("zhCN", function() return {
-- 		["ChatFrames"] = "聊天框架",
-- 		["ChatFrame manipulation options."] = "聊天框架设置选项。",
-- 		["Toggle"] = "切换",
-- 		["Toggle the module on and off."] = "切换此模块的打开与关闭。",
-- } end)
-- 
-- L:RegisterTranslations("koKR", function() return {
-- 	["ChatFrames"] = "대화창",
-- 	["Chat window frame parameter options."] = "대화창 제한 설정입니다.",
-- 	["sizing_name"] = "대화창 크기 제한",
-- 	["sizing_desc"] = "대화창 크기 제한을 설정합니다.",
-- 	["minchatwidth_name"] = "최소 넓이 설정",
-- 	["minchatwidth_desc"] = "대화창의 최소 넓이를 설정합니다.",
-- 	["minchatheight_name"] = "최소 높이 설정",
-- 	["minchatheight_desc"] = "대화창의 최소 높이를 설정합니다.",
-- 	["maxchatwidth_name"] = "최대 넓이 설정",
-- 	["maxchatwidth_desc"] = "대화창의 최대 넓이를 설정합니다.",
-- 	["maxchatheight_name"] = "최대 높이 설정",
-- 	["maxchatheight_desc"] = "대화창의 최대 높이를 설정합니다.",
-- 	["restore_name"] = "접속 시 주 대화창 선택",
-- 	["restore_desc"] = "접속 시 첫번째 대화창을 자동으로 선택합니다.",
-- } end)
-- 
-- L:RegisterTranslations("zhTW", function() return {
--     ["ChatFrames"] = "聊天框架",
--     ["ChatFrame manipulation options."] = "聊天框架設定選項。",
--     ["Toggle"] = "切換",
--     ["Toggle the module on and off."] = "切換打開或關閉此模組。",
-- } end)
--
-- L:RegisterTranslations("esES", function() return {
--     ["ChatFrames"] = "Marcos de Chat",
--     ["ChatFrame manipulation options."] = "Opciones de manipulaci\195\179n de los marcos de chat",
--     ["MinWidth"] = "Anchura m\195\173nima",
--     ["Set the minimum width of the chat windows."] = "Establece la anchura m\195\173nima de las ventanas de chat",
--     ["MinHeight"] = "Altura m\195\173nima",
--     ["Set the minimum height of the chat windows."] = "Establece la altura m\195\173nima de las ventanas de chat",
--     ["MaxWidth"] = "Anchura m\195\161xima",
--     ["Set the maximum width of the chat windows."] = "Establece la anchura m\195\161xima de las ventanas de chat",
--     ["MaxHeight"] = "Altura m\195\161xima",
--     ["Set the maximum height of the chat windows."] = "Establece la altura m\195\161xima de las ventanas de chat",
--     ["Toggle"] = "Activar",
--     ["Toggle the module on and off."] = "Activa y desactiva este m\195\179dulo.",
-- } end)
--
-- L:RegisterTranslations("deDE", function() return {
--     ["ChatFrames"] = "Chatfenster",
--     ["ChatFrame manipulation options."] = "Chatfenster Manipulation Optionen.",
--     ["MinWidth"] = "MinBreite",
--     ["Set the minimum width of the chat windows."] = "Setzt die minimum Breite der Chatfenster fest.",
--     ["MinHeight"] = "MinH\195\182he",
--     ["Set the minimum height of the chat windows."] = "Setzt die minimum H\195\182he der Chatfenster fest.",
--     ["MaxWidth"] = "MaxBreite",
--     ["Set the maximum width of the chat windows."] = "Setzt die maximum Breite der Chatfenster fest.",
--     ["MaxHeight"] = "MaxH\195\182he",
--     ["Set the maximum height of the chat windows."] = "Setzt die maximum H\195\182he der Chatfenster fest.",
--     ["Toggle"] = "Einschalten",
--     ["Toggle the module on and off."] = "Schaltet dieses Modul an und aus.",
-- } end)

Prat_ChatFrames = Prat:NewModule(Prat:RequestModuleName("PratChatFrames"))

Prat_ChatFrames.revision = tonumber(string.sub("$Revision: 24018 $", 12, -3))

Prat_ChatFrames.status = "TAINT"

Prat_ChatFrames.defaultDB = {
        on = true,
        initialized = false,
        defaultminchatwidth = 160,
        defaultmaxchatwidth = 800,
        defaultminchatheight = 120,
        defaultmaxchatheight = 600,
        minchatwidth = 160,
        maxchatwidth = 800,
        minchatheight = 120,
        maxchatheight = 600,
        restore = true,
}


local cat = Prat.Categories
Prat_ChatFrames.Categories = { cat.FRAMES, cat.FORMATTING, cat.BEHAVIOUR }

local function range_opt(vmin, vmax, vstep)
    return { type = "range", min = vmin, max = vmax, step = vstep }
end

Prat_ChatFrames.toggleOptions = { restore=320 , sizing_pass={ minchatwidth = range_opt(25,1024,1), 
                                                              minchatheight = range_opt(25,1280,1),  
                                                              maxchatwidth = range_opt(25,1024,1),  
                                                              maxchatheight = range_opt(25,1280,1) }}
Prat_ChatFrames.moduleOptions = {}

function Prat_ChatFrames:GetModuleOptions()
    self.moduleOptions = {
        name = L["ChatFrames"],
        desc = L["Chat window frame parameter options."],
        type = "group",
        args = {
            optsep195 = {
                order = 195,
                type = 'header',        
            },  
            lockPetBar = {
                type = "toggle",
                order = 318,            
                name = "Lock the Pet Action Bar",
                desc = "Lock the Pet Action Bar and show it if not in combat. THIS SETTING IS NOT SAVED",
                get = function() return PetActionBarFrame.locked and PetActionBarFrame:IsShown()  end,
                set = function(v) return Prat_ChatFrames:LockPetActionBar(v) end,
                disabled = function() return InCombatLockdown() end,
            },            
                        
        }
    }
   	return self.moduleOptions
end

function Prat_ChatFrames:OnModuleInit()
    if not self.db.profile.initialized then
        self:GetDefaults()
    end
end

function Prat_ChatFrames:OnModuleEnable()
	self:RegisterEvent("AceEvent_FullyInitialized")
	self:RegisterEvent("Prat_PetActionBarTainted")

    self:ConfigureAllChatFrames()
end

function Prat_ChatFrames:OnModuleDisable()
    self:ConfigureAllChatFrames()
end


function Prat_ChatFrames:ModuleSetOption(name, val)
    self.super.ModuleSetOption(self, name, val)
    
    self:ConfigureAllChatFrames()
end



function Prat_ChatFrames:Prat_PetActionBarTainted()
    Prat:Print(CLR:Colorize("ff2020", "WARNING: ")..
               CLR:Colorize("ffff20", "Your pet action bar has become tainted. Enable the ")..
               CLR:Colorize("8080ff", "'Lock the Pet Action Bar'")..
               CLR:Colorize("ffff20", " option in the ")..
               CLR:Colorize("8080ff", "ChatFrames")..
               CLR:Colorize("ffff20", " module, or ")..
               CLR:Colorize("8080ff", "/rl")..
               CLR:Colorize("ffff20", " to reload your UI"))
end


function Prat_ChatFrames:LockPetActionBar(b)    
    if b then 
        if not InCombatLockdown() then
            PetActionBarFrame.locked = nil
            PetActionBarFrame:Show()
        end

        LockPetActionBar()
        if not self:IsHooked("UnlockPetActionBar") then 
            self:Hook("UnlockPetActionBar", true)
        end
    else
        if self:IsHooked("UnlockPetActionBar") then 
            self:Unhook("UnlockPetActionBar", true)
        end
        UnlockPetActionBar()
        if not (InCombatLockdown() or UnitExists("pet")) then
            PetActionBarFrame:Hide()
        end
    end    
    
    return b
end
    
function Prat_ChatFrames:UnlockPetActionBar()
    self:Debug("UnlockPetActionBar - Override")
    PetActionBarFrame.locked = 1 -- NO
end

--[[------------------------------------------------
	Core Functions
------------------------------------------------]]--

-- Make ChatFrame1 the selected chat frame
function Prat_ChatFrames:AceEvent_FullyInitialized()
    if self.db.profile.restore then 
    	FCF_SelectDockFrame(ChatFrame1)
    end
end

function Prat_ChatFrames:ConfigureAllChatFrames()
    for i = 1,NUM_CHAT_WINDOWS do
        self:SetParameters(i, self.db.profile.on)
    end
end

function Prat_ChatFrames:GetDefaults()
    local cf = getglobal("ChatFrame1")
    local defaultminwidth, defaultminheight = cf:GetMinResize()
    local defaultmaxwidth, defaultmaxheight = cf:GetMaxResize()
    self.db.profile.defaultminchatwidth = defaultminwidth
    self.db.profile.defaultmaxchatwidth = defaultmaxwidth
    self.db.profile.defaultminchatheight = defaultminheight
    self.db.profile.defaultmaxchatheight = defaultmaxheight
    self.db.profile.initialized = true
end

function Prat_ChatFrames:SetParameters(id,enabled)
    local cf = getglobal("ChatFrame"..id)
    if enabled then
        cf:SetMinResize(self.db.profile.minchatwidth,self.db.profile.minchatheight)
        cf:SetMaxResize(self.db.profile.maxchatwidth,self.db.profile.maxchatheight)
    else
        cf:SetMinResize(self.db.profile.defaultminchatwidth,self.db.profile.defaultminchatheight)
        cf:SetMaxResize(self.db.profile.defaultmaxchatwidth,self.db.profile.defaultmaxchatheight)
    end
end